pub struct PreparedWrite { /* private fields */ }Expand description
Unsigned owner-write transaction plus the SQL and OSW1 intent it commits to.
Implementations
Sourceimpl PreparedWrite
impl PreparedWrite
Sourcepub fn timestamp(&self) -> f64
pub fn timestamp(&self) -> f64
Return the Octra transaction timestamp captured during preparation.
Sourcepub fn public_key(&self) -> &str
pub fn public_key(&self) -> &str
Return the signing public key encoded for Octra RPC.
Sourcepub fn ou(&self) -> &str
pub fn ou(&self) -> &str
Return the Octra unit budget that will be signed into the transaction.
Sourcepub fn owner_write(&self) -> &PreparedOwnerWrite
pub fn owner_write(&self) -> &PreparedOwnerWrite
Return the prepared OSW1 owner-write metadata.
Sourcepub fn safety(&self) -> OperationSafety
pub fn safety(&self) -> OperationSafety
Return the operation’s declarative safety metadata.